scripts/install-i18n.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 8235
78e6d29eb773
diff -r 44e15eda6506 -r e8fc383322f7 scripts/install-i18n.py
--- a/scripts/install-i18n.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/scripts/install-i18n.py	Wed Jan 06 13:47:01 2021 +0100
@@ -3,10 +3,10 @@
 
 # Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6's translation files.
 
 """
-Installation script for the eric6 IDE translation files.
+Installation script for the eric IDE translation files.
 """
 
 import sys
@@ -17,11 +17,11 @@
 try:
     from eric6config import getConfig
 except ImportError:
-    print("The eric6 IDE doesn't seem to be installed. Aborting.")
+    print("The eric IDE doesn't seem to be installed. Aborting.")
     sys.exit(1)
 except SyntaxError:
     # an incomplete or old config file was found
-    print("The eric6 IDE seems to be installed incompletely. Aborting.")
+    print("The eric IDE seems to be installed incompletely. Aborting.")
     sys.exit(1)
     
 
@@ -3,10 +3,10 @@
 # Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the install script for eric6's translation files.
+# This is the install script for eric's translation files.
 
 """

eric ide

mercurial